""" Copyright start
  Copyright (C) 2008 - 2025 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end """
"""
Django settings for archival project.

Generated by 'django-admin startproject' using Django 3.1.

For more information on this file, see
https://docs.djangoproject.com/en/3.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/3.1/ref/settings/
"""

import os
import configparser
import subprocess
import socket
from os.path import abspath, dirname, join
from pathlib import Path

from .utils import all_config

ALL_CONFIG = all_config
DJANGO_ROOT = dirname(dirname(abspath(__file__)))
CONFIG_DIR = join(DJANGO_ROOT, 'configs')
APPLIANCE_PUBLIC_KEY = join(CONFIG_DIR, 'APPLIANCE_PUBLIC_KEY')
APPLIANCE_PRIVATE_KEY = join(CONFIG_DIR, 'APPLIANCE_PRIVATE_KEY')
ARCHIVAL_PUBLIC_KEY = join(CONFIG_DIR, 'archivalpublic.key')
ARCHIVAL_PRIVATE_KEY = join(CONFIG_DIR, 'archivalprivate.key')

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve(strict=True).parent.parent

CONFIG_DIR = join(BASE_DIR, 'configs')
application_config = configparser.RawConfigParser()
application_config.read(join(CONFIG_DIR, 'config.ini'))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/3.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '+vfx4&=b!#^2c9tv)cgvh27%7(w6=65t$3!odu38x+e*2@h*9s'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = application_config.getboolean('application', 'debug')

ALLOWED_HOSTS = ['localhost', '127.0.0.1']
for key in [APPLIANCE_PUBLIC_KEY, APPLIANCE_PRIVATE_KEY, ARCHIVAL_PUBLIC_KEY, ARCHIVAL_PRIVATE_KEY]:
    with open(key, 'r') as key_file:
        os.environ.setdefault(key.split(os.sep)[-1], key_file.read().strip())

APPLIANCE_PUBLIC_KEY = os.getenv('APPLIANCE_PUBLIC_KEY', '')
APPLIANCE_PRIVATE_KEY = os.getenv('APPLIANCE_PRIVATE_KEY', '')
ARCHIVAL_PUBLIC_KEY = os.getenv('archivalpublic.key', '')
ARCHIVAL_PRIVATE_KEY = os.getenv('archivalprivate.key', '')
HMAC_USER = 'hmac_user'

CRUD_HUB_URL = 'https://' + ALL_CONFIG.get('application', 'app_host')

MAX_RELATIONSHIP_CONFIG = ALL_CONFIG.get('application', 'max_relationship_counts')
MAX_RELATIONSHIP_COUNTS = '2' if int(MAX_RELATIONSHIP_CONFIG) < 2 else '100' if int(
    MAX_RELATIONSHIP_CONFIG) >= 100 else MAX_RELATIONSHIP_CONFIG
MAX_RECORD_COUNT = 100

# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    "django.contrib.postgres",
    'psqlextra',
    'rest_framework',
    'django_filters'
]

# APPLICATION MODULES
INSTALLED_APPS += [
    'core',
    'entities'
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'archival.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'archival.wsgi.application'

# Database
# https://docs.djangoproject.com/en/3.1/ref/settings/#databases


DB_HOST = ALL_CONFIG.config.get('postgres_archival').get('pg_archival_host')
DB_PORT = ALL_CONFIG.config.get('postgres_archival').get('pg_archival_port')
DB_NAME = ALL_CONFIG.get('database', 'db_name')
DB_USER = ALL_CONFIG.config.get('postgres_archival').get('pg_archival_user')
DB_PASSWORD = ALL_CONFIG.config.get('postgres_archival').get('pg_archival_password')

# Decrypt DB password
if DB_PASSWORD:
    output = subprocess.check_output(
        ['/opt/cyops-auth/.env/bin/python', '/opt/cyops/scripts/manage_passwords.py', '--decrypt',
         DB_PASSWORD, 'jQp3(7@jod#j38d1']
    ).strip().decode()
    if not output.startswith('Password:'):
        raise Exception('DB Password decrypt failed with Error: %s for Password : %s' % output)
    else:
        DB_PASSWORD = output[len('Password:'):]

DATABASES = {
    'default': {
        'ENGINE': 'psqlextra.backend',
        'USER': DB_USER,
        'PASSWORD': DB_PASSWORD,
        'NAME': DB_NAME,
        'HOST': DB_HOST,
        'PORT': DB_PORT,
        'OPTIONS': {
            'client_encoding': 'UTF-8'
        }

    }
}

# Password validation
# https://docs.djangoproject.com/en/3.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]

# Internationalization
# https://docs.djangoproject.com/en/3.1/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True

CH_MAX_RETRY_COUNT = 5

APP_LOG_FILE_PATH = ALL_CONFIG.get('logging', 'app_log_file_path')
APP_LOG_FILE_SIZE = eval(ALL_CONFIG.get('logging', 'app_log_file_size'))
APP_LOG_FILE_BACKUP_COUNT = eval(ALL_CONFIG.get('logging', 'app_log_file_backup_count'))

ARCHIVAL_LOGGER_LEVEL = ALL_CONFIG.get('logging', 'archival_logger_level')
DJANGO_LOGGER_LEVEL = ALL_CONFIG.get('logging', 'django_logger_level')

LOGGING = {
    'version': 1,
    'disable_existing_loggers': True,
    'formatters': {
        'verbose': {
            'format': '[%(asctime)s] %(levelname)s %(name)s %(module)s %(funcName)s(): %(message)s',
            'datefmt': '%Y-%m-%d %H:%M:%S'
        }
    },
    'handlers': {
        'app_logger': {
            'class': 'logging.handlers.RotatingFileHandler',
            'filename': APP_LOG_FILE_PATH,
            'maxBytes': APP_LOG_FILE_SIZE,
            'backupCount': APP_LOG_FILE_BACKUP_COUNT,
            'formatter': 'verbose'
        }
    },
    'loggers': {
        'archival': {
            'handlers': ['app_logger'],
            'level': ARCHIVAL_LOGGER_LEVEL,
            'propagate': False
        },
        'annotation': {
            'handlers': ['app_logger'],
            'level': ARCHIVAL_LOGGER_LEVEL,
            'propagate': False
        },
        'django.request': {
            'handlers': ['app_logger'],
            'level': ARCHIVAL_LOGGER_LEVEL,
            'propagate': False
        }
    }
}

REST_FRAMEWORK = {
    'DEFAULT_PAGINATION_CLASS': 'archival.pagination.ArchivalPageNumberPagination',
    'PAGE_SIZE': 30,
    'DEFAULT_RENDERER_CLASSES': [
        'rest_framework.renderers.BrowsableAPIRenderer',
        'rest_framework.renderers.JSONRenderer',
    ],
    'DEFAULT_AUTHENTICATION_CLASSES': [
        'rest_framework.authentication.SessionAuthentication',
        'utils.schemes.HmacAuthenticationScheme',
    ]
}

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/3.1/howto/static-files/

STATIC_URL = '/static/'
STATIC_ROOT = join(DJANGO_ROOT, 'static/')
MAX_ITEM_PER_REQUEST = 30
CHUNK_SIZE_FOR_DELETE = 30
HOSTNAME = socket.gethostname()
ARCHIVAL_CONFIG_OBJECT_LIST = None

SYSLOG_CONN = None
SYSLOG_LOGGER = None
RELEASE_VERSION = None
