#!/opt/cyops-archival/.env/bin/python
""" Copyright start
  Copyright (C) 2008 - 2025 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end """
import os
import subprocess

import psycopg2
import yaml

CONF_FILE = '/opt/cyops/configs/database/db_config.yml'
LOG_FILES = [
    "/var/log/cyops/cyops-archival/archival.log",
    "/var/log/cyops/cyops-archival/ssl_cyops_archival_access.log",
    "/var/log/cyops/cyops-archival/ssl_cyops_archival_error.log",
    "/var/log/cyops/cyops-archival/uwsgi.log"
]


def read_config_file(conffile=CONF_FILE):
    with open(conffile, 'r') as config_file_fp:
        local_config = yaml.load(config_file_fp, Loader=yaml.FullLoader)
    return local_config


def create_log_folder():
    archival_log_dir = '/var/log/cyops/cyops-archival/'
    if not os.path.isdir(archival_log_dir):
        os.mkdir(archival_log_dir)
        for log_file in LOG_FILES:
            with open(log_file, 'w') as f:
                pass
        os.system('chown -R nginx:nginx /var/log/cyops/cyops-archival')


def create_archival_app_keys():
    print("==================================")
    print("Creating archival app keys")
    print("==================================")
    if not os.path.exists('/etc/pki/cyops/archivalprivate.key'):
        subprocess.call(["/opt/cyops-auth/.env/bin/python",
                         "/opt/cyops-auth/defaultappliance.py",
                         "--app", "archival",
                         "generate-app-keys"])
        print("==================================")
        print("Done: Created archival app keys")
        return
    print("==================================")
    print("Archival key already created")


def create_postgres_archival_section():
    config = read_config_file()
    if not config.get('postgres_archival', {}).get('pg_archival_host'):
        with open('/opt/cyops/configs/database/db_config.yml', 'w') as outfile:
            config['postgres_archival'] = {
                "pg_archival_external": config.get('postgres').get('pg_external'),
                "pg_archival_host": config.get('postgres').get('pg_host'),
                "pg_archival_password": config.get('postgres').get('pg_password'),
                "pg_archival_port": config.get('postgres').get('pg_port', '5432'),
                "pg_archival_user": config.get('postgres').get('pg_user'),
                "pg_archival_use_ssl": config.get('postgres').get('pg_use_ssl'),
                "pg_archival_ssl_cert_path": config.get('postgres').get('pg_ssl_cert_path'),
            }
            yaml.dump(config, outfile, default_flow_style=False)


def create_database():
    config = read_config_file()
    db_host = config.get('postgres').get('pg_host')
    db_port = config.get('postgres').get('pg_port', '5432')
    db_user = config.get('postgres').get('pg_user')
    db_password = config.get('postgres').get('pg_password')
    # Decrypt DB password
    if db_password:
        output = subprocess.check_output(
            ['/opt/cyops-auth/.env/bin/python', '/opt/cyops/scripts/manage_passwords.py', '--decrypt',
             db_password, 'jQp3(7@jod#j38d1']
        ).strip().decode()
        if not output.startswith('Password:'):
            raise Exception('DB Password decrypt failed with Error: %s for Password : %s' % output)
        else:
            db_password = output[len('Password:'):]
    try:
        conn = psycopg2.connect(database="data_archival", user=db_user, password=db_password,
                                host=db_host, port=db_port)
        print("Database data_archival already exists, exiting.")
        return
    except psycopg2.OperationalError as e:
        print("Creating database data_archival")
        conn = psycopg2.connect(database="venom", user=db_user, password=db_password,
                                host=db_host, port=db_port)
    conn.autocommit = True
    cursor = conn.cursor()
    sql = '''CREATE database data_archival''';
    cursor.execute(sql)
    conn.close()


if __name__ == '__main__':
    create_postgres_archival_section()
    create_database()
    create_archival_app_keys()
    create_log_folder()
